#ifndef __GNOME_SOUND_H__
#define __GNOME_SOUND_H__ 1

#include "gnome-defs.h"
#include <glib.h>
BEGIN_GNOME_DECLS

/*
 * Copyright (C) 1998 Stuart Parmenter and Elliot Lee
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option) 
 * any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

/* Use this with the Esound functions */
extern int gnome_sound_connection;

/* Initialize esd connection */
void gnome_sound_init(const char *hostname);

/* Closes esd connection */
void gnome_sound_shutdown(void);

/* Returns the Esound sample ID for the sample */
int gnome_sound_sample_load(const char *sample_name, const char *filename);

/* Loads sample, plays sample, frees sample */
void gnome_sound_play (const char * filename);

#ifdef HAVE_ESD
#include <esd.h>

#ifdef G_MODULE_ESD
#include <gmodule.h>

extern int esd_open_sound_func( const char *host );
extern int esd_sample_cache_func( int esd, esd_format_t format, const int rate,
                      const int length, const char *name );
extern int esd_confirm_sample_cache_func( int esd );
extern int esd_sample_free_func( int esd, int sample );
extern int esd_sample_play_func( int esd, int sample );
extern int esd_close_func( int esd );
extern int esd_sample_getid_func( int esd, const char *name);
extern int esd_set_stream_pan_func( int esd, int stream_id,int left_scale, int right_scale ); 
extern int esd_set_default_sample_pan_func( int esd, int sample_id,int left_scale, int right_scale ); 
extern esd_info_t *esd_get_all_info_func( int esd );
extern void esd_free_all_info_func( esd_info_t *info );
extern int esd_monitor_stream_func( esd_format_t format, int rate,const char *host, const char *name ); 
extern int esd_record_stream_func( esd_format_t format, int rate, const char *host, const char *name );
extern int esd_standby_func( int esd );
extern int esd_resume_func( int esd );
extern esd_standby_mode_t esd_get_standby_mode_func( int esd );

extern AFfilehandle afOpenFile_func(const char *filename, const char *mode,
        AFfilesetup setup);  
extern int afCloseFile_func(AFfilehandle file);
extern int afReadFrames_func(AFfilehandle, int track, void *buffer, int frameCount);
extern int afGetChannels_func(AFfilehandle, int track);
extern void afGetSampleFormat_func(AFfilehandle file, int track, int *sampfmt,
        int *sampwidth_func);     
extern double afGetRate_func(AFfilehandle, int track);
extern AFframecount afGetFrameCount_func(AFfilehandle file, int track);

#define esd_open_sound esd_open_sound_func
#define esd_sample_cache esd_sample_cache_func
#define esd_confirm_sample_cache esd_confirm_sample_cache_func
#define esd_sample_free esd_sample_free_func
#define esd_sample_play esd_sample_play_func
#define esd_close esd_close_func
#define esd_sample_getid esd_sample_getid_func
#define esd_set_stream_pan esd_set_stream_pan_func
#define esd_set_default_sample_pan esd_set_default_sample_pan_func
#define esd_get_all_info esd_get_all_info_func
#define esd_free_all_info esd_free_all_info_func
#define esd_monitor_stream esd_monitor_stream_func
#define esd_record_stream esd_record_stream_func
#define esd_standby esd_standby_func
#define esd_resume esd_resume_func
#define esd_get_standby_mode esd_get_standby_mode_func
 
#define afOpenFile afOpenFile_func
#define afCloseFile afCloseFile_func
#define afReadFrames afReadFrames_func
#define afGetChannels afGetChannels_func
#define afGetSampleFormat afGetSampleFormat_func
#define afGetRate afGetRate_func
#define afGetFrameCount afGetFrameCount_func

#endif
#endif

END_GNOME_DECLS

#endif /* __GNOME_SOUND_H__ */
